==> james-project-3.7.6-source-release.zip: james-project/server/container/guice/mailbox/src/main/java/org/apache/james/modules/mailbox/PreDeletionHookLoaderImpl.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.modules.mailbox;

import org.apache.james.mailbox.extension.PreDeletionHook;
import org.apache.james.utils.ClassName;
import org.apache.james.utils.GuiceGenericLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.inject.Inject;

public class PreDeletionHookLoaderImpl implements PreDeletionHookLoader {
    private static final Logger LOGGER = LoggerFactory.getLogger(PreDeletionHookLoaderImpl.class);

    private final GuiceGenericLoader genericLoader;

    @Inject
    PreDeletionHookLoaderImpl(GuiceGenericLoader guiceGenericLoader) {
        this.genericLoader = guiceGenericLoader;
    }

    @Override
    public PreDeletionHook createHook(PreDeletionHookConfiguration configuration) throws ClassNotFoundException {
        ClassName hookClass = new ClassName(configuration.getClazz());
        LOGGER.info("Loading user registered mailbox message deletionHook {}", hookClass);
        return genericLoader.instantiate(hookClass);
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/mailbox/src/main/java/org/apache/james/modules/mailbox/PreDeletionHookLoaderImpl.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.modules.mailbox;

import org.apache.james.mailbox.extension.PreDeletionHook;
import org.apache.james.utils.ClassName;
import org.apache.james.utils.GuiceLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.inject.Inject;

public class PreDeletionHookLoaderImpl implements PreDeletionHookLoader {
    private static final Logger LOGGER = LoggerFactory.getLogger(PreDeletionHookLoaderImpl.class);

    private final GuiceLoader guiceLoader;

    @Inject
    PreDeletionHookLoaderImpl(GuiceLoader guiceLoader) {
        this.guiceLoader = guiceLoader;
    }

    @Override
    public PreDeletionHook createHook(PreDeletionHookConfiguration configuration) throws ClassNotFoundException {
        ClassName hookClass = new ClassName(configuration.getClazz());
        LOGGER.info("Loading user registered mailbox message deletionHook {}", hookClass);
        return guiceLoader.instantiate(hookClass);
    }
}
